## Introduction
This is the Sunholo Python project, a comprehensive toolkit for working with language models and vector stores on Google Cloud Platform. It provides a wide range of functionalities and utilities to facilitate the development and deployment of language model applications.

Please refer to the website for full documentation at https://dev.sunholo.com/

## Tests via pytest

If loading from GitHub, run tests:

```bash
pip install pytest
pip install . --use-feature=in-tree-build
pytest tests
```

## Demos

Using https://github.com/charmbracelet/vhs

```sh
vhs record > cassette.tape
```

Then make gif:

```sh
vhs docs/tapes/config-list.tape
```



```
   Copyright [2024] [Holosun ApS]

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
```

